@@ -364,7 +364,7 @@ label_1:
             for(i=0; i<10;i++)
             if ((mouse_info.col > fkPos[i]) && (mouse_info.col < fkPos[i+1]))
             {  if (i==9)ink='0'; else ink='1'+i;}
-         } // else if ( (mouse_info.col < col ) || (mouse_info.col >col+ncol+1) || (mouse_info.row < row ) || (mouse_info.row >row+height+1) )   goto label_3; 
+         } else if ( (mouse_info.col < col ) || (mouse_info.col >col+ncol+1) || (mouse_info.row < row ) || (mouse_info.row >row+height+1) )   goto label_3; 
          else  
          {  mousePos = mouse_info.row - row;
             if (mousePos==0)
