@@ -3,7 +3,7 @@
 #include <math.h>
 #include "polint.h"
 
-static int  leftXN(int n,int dim,  double * xa, double x)
+static int  leftXN(int n,int dim, const  double * xa, const double x)
 {  int k1,k2,k3;
 
    k1=n/2;                         
@@ -29,7 +29,7 @@ static int  leftXN(int n,int dim,  double * xa, double x)
    return k1+1-n/2;
 }
 
-double  polintN(double x, int n,  double *xa, double *ya)
+double  polintN(double x, int n,  const double *xa, const double *ya)
 {  double z[20];
    int i,m;
    for(i=0;i<n;i++) z[i]=ya[i];
@@ -39,7 +39,7 @@ double  polintN(double x, int n,  double *xa, double *ya)
 }
 
 
-double polint3(double x, int dim,  double *xa, double *ya)
+double polint3(double x, int dim, const  double *xa, const double *ya)
 { 
   if(dim<4) return  polintN(x,dim,xa, ya);
   if((xa[0]<xa[dim-1] && x<=xa[1]) || 
