@@ -71,18 +71,18 @@ void decay_0(int nvin,  REAL  amm1, REAL  amm2, double *factor,double *Emax, iDe
     
 if(vv<0)printf("decay0: vv=%e m1=%e m2=%e\n", vv,amm1, amm2);
     if(vv<0) { vv=0; fprintf(stderr,"decay_0: negative incoming mass\n");}
-    v0 = sqrt(vv);
+    v0 = Sqrt(vv);
     e0v = 1 / v0;
 /* Computing 2nd power */
     summ = am1 + am2;
     diffm = am1 - am2;
     if(v0<summ){pout=0;  fprintf(stderr,"decay_0: virtual decay\n");}
-    else pout = sqrt((v0-summ)*(v0+ summ)*(v0-diffm)*(v0+diffm))/(v0*2);
-    e1out = sqrt(am1*am1 + pout*pout);
-    e2out = sqrt(am2*am2 + pout*pout);
+    else pout = Sqrt((v0-summ)*(v0+ summ)*(v0-diffm)*(v0+diffm))/(v0*2);
+    e1out = Sqrt(am1*am1 + pout*pout);
+    e2out = Sqrt(am2*am2 + pout*pout);
     *factor = pout/(c_pi__ * (e1out + e2out));
     chY=V[4*nvin-4]/v0;
-    shY=sqrt(chY*chY-1);
+    shY=Sqrt(chY*chY-1);
     Emax[0]= e1out*chY+pout*shY;
     Emax[1]= e2out*chY+pout*shY;    
 }
@@ -93,7 +93,7 @@ void decay_1(int nvpole, REAL *hsum, REAL *hdif,iDecay*memDecay,REAL*V)
     vp = vdot4(n0, nvpole,V);
     pp = vdot4(nvpole, nvpole,V);
     p0 = e0v * vp;
-    p1 = sqrt(p0*p0 - pp);
+    p1 = Sqrt(p0*p0 - pp);
 
     *hdif = p1 * 2 * pout;
     hsum[0] = pp + am1*am1 + p0 * 2 * e1out;
@@ -105,7 +105,7 @@ void decay_2(int nvout1,  double * parcos,iDecay*memDecay,REAL*V)
     oo = vdot4(nvout1, nvout1,V);
     vo = vdot4(n0, nvout1,V);
     po = vdot4(n1, nvout1,V);
-    *parcos = (po*vv - vp*vo)/sqrt((pp*vv - vp*vp) * (oo*vv - vo*vo));
+    *parcos = (po*vv - vp*vo)/Sqrt((pp*vv - vp*vp) * (oo*vv - vo*vo));
 }
 
 void decay_3(int nvath, REAL parcos, REAL parfi, int nvout1, int nvout2,iDecay*memDecay,REAL*V)
@@ -120,7 +120,7 @@ void decay_3(int nvath, REAL parcos, REAL parfi, int nvout1, int nvout2,iDecay*m
     e1v = -e1p * p0 * e0v;
     a0 = e0v * va;
     a1 = -(e1v * va + e1p * pa);
-    a2 = sqrt(a0*a0 - a1*a1 - aa);
+    a2 = Sqrt(a0*a0 - a1*a1 - aa);
     e2a = 1 / a2;
     e2p = -e2a * a1 * e1p;
     e2v = -e2a * (a0 * e0v + a1 * e1v);
@@ -128,10 +128,10 @@ void decay_3(int nvath, REAL parcos, REAL parfi, int nvout1, int nvout2,iDecay*m
     lparcos=parcos;
     if(lparcos>=1) {lparcos=1; lparsin=0;} 
     else if(lparcos<=-1){lparcos=-1;lparsin=0;}
-    else   lparsin = sqrt((1 - lparcos) * (lparcos + 1));
+    else   lparsin = Sqrt((1 - lparcos) * (lparcos + 1));
     
-    sinfi = sin((double)parfi);
-    cosfi = cos((double)parfi);
+    sinfi = Sin(parfi);
+    cosfi = Cos(parfi);
     n3 = nvout1;
     n2 = nvath;
     eps4(n0, n1, n2, n3,V);
@@ -139,7 +139,7 @@ void decay_3(int nvath, REAL parcos, REAL parfi, int nvout1, int nvout2,iDecay*m
     cinp = pout*(lparcos*e1v + lparsin*cosfi*e2v);
     cpol = pout*(lparcos*e1p + lparsin*cosfi*e2p);
     cath = pout*lparsin*cosfi*e2a;
-    ceps = pout*lparsin*sinfi/sqrt(-vdot4(n3, n3,V));
+    ceps = pout*lparsin*sinfi/Sqrt(-vdot4(n3, n3,V));
 
 	
     for (i = 0; i <= 3; ++i) 
