@@ -44,7 +44,6 @@ int checkParam(void)
 { int err;
 
   err=calcMainFunc();
-
   if(err>0)
   {  char mess[100];
      sprintf(mess,"Can not evaluate constrained parameter '%s' ",
@@ -259,7 +258,7 @@ void show_depend(int x, int y)
       correctStr(10,17,"File name: ",fname,50,1);
       FILE *f =fopen(fname,"w");
       for(int i=0; i< nModelFunc;i++) 
-         fprintf(f, " %10.10s %E\n", varNames[i+nModelVars],varValues[i+nModelVars]); 
+         fprintf(f, " %10.10s %E\n", varNames[i+nModelVars],(double)varValues[i+nModelVars]); 
       fclose(f);
        continue;
      }
@@ -323,7 +322,7 @@ void show_depend(int x, int y)
                *vPos=val2; 
                for(i=0;i<nModelFunc;i++) varValues[1+nModelVars+i]=allfunc[i];
 
-               if(!(NaN||Esc)) plot_1(xMin,xMax,nPoints,f,NULL,"Parameter depndence",
+               if(!(NaN||Esc)) plot_1(xMin,xMax,nPoints,f,NULL,"Parameter dependence",
                                name2,name1);
                                
             } else messanykey(16,5," Correct input is \n"
