@@ -26,8 +26,8 @@ static void LorRot(REAL rapidity, int ntot,REAL*pvect)
   int nv;
   
   if(rapidity)
-  {   sh = sinh(rapidity);
-      ch = sqrt(sh * sh + 1);
+  {   sh = Sinh(rapidity);
+      ch = Sqrt(sh * sh + 1);
       for(nv=4*ntot-4; nv>=0; nv -=4)
       {  ee = pvect[nv];
          pp = pvect[nv+3];
@@ -39,8 +39,8 @@ static void LorRot(REAL rapidity, int ntot,REAL*pvect)
 
 static void AzimuthRot(REAL fi, int ntot,REAL*pvect)
 {
-  REAL sn = sin(fi);
-  REAL cn = cos(fi);
+  REAL sn = Sin(fi);
+  REAL cn = Cos(fi);
   int i;
     
   for(i=0;i<ntot;i++)
@@ -56,9 +56,9 @@ static void AzimuthRot(REAL fi, int ntot,REAL*pvect)
 
 static void Rot3D(double  cn0 , double fi, double psi, int ntot, REAL *pvect)
 {
-   REAL cn=cn0, sn=sqrt(fabs(1-cn*cn));
+   REAL cn=cn0, sn=Sqrt(fabs(1-cn*cn));
    REAL fi_1=fi;
-   REAL E[3]={ cn, sn*sin(fi_1), sn*cos(fi_1)};
+   REAL E[3]={ cn, sn*Sin(fi_1), sn*Cos(fi_1)};
    REAL EPS[3][3]= { {  0,  -E[2], E[1]},
                      { E[2],   0 ,-E[0]},
                      {-E[1], E[0],  0  }  }; 
@@ -76,12 +76,12 @@ static void Rot3D(double  cn0 , double fi, double psi, int ntot, REAL *pvect)
   x2=M_PI;
   for(;;)
   { x3=0.5*(x1+x2);
-    f3=x3-psi-sin(x3);
+    f3=x3-psi-Sin(x3);
     if(f3<0) x1=x3;else x2=x3;
     if(fabs(f3)<1.E-4) break;
   }
                              
-  cn2=cos(x3),sn2=sin(x3);
+  cn2=Cos(x3),sn2=Sin(x3);
   
   for(i=0;i<3;i++) for(j=0;j<3;j++) ROT[i][j]= (cn2-1)*P[i][j] + sn2*EPS[i][j]; 
       
@@ -115,7 +115,7 @@ static REAL  cmfun( REAL E,REAL PM1,REAL PM2)
   e2=E*E;
   s=PM1+PM2;
   d=PM1-PM2;  
-  return sqrt((e2-s*s)*(e2-d*d))/(2*E);     
+  return Sqrt((e2-s*s)*(e2-d*d))/(2*E);     
 }
 
 
@@ -185,12 +185,12 @@ int mkmom(double*x,double*tfact,double*xp1,double*xp2,REAL*pvect)
 /* **   MOMENTS */
     if(nout_int==1)
     { 
-       REAL s=pm[0]+pm[1], d=pm[0]-pm[1], p=sqrt((pm[2]-s)*(pm[2]+ s)*(pm[2]-d)*(pm[2]+d))/(2*pm[2]);
-       REAL e1=sqrt(p*p+pm[0]*pm[0]), e2=sqrt(p*p+pm[1]*pm[1]);
-       REAL y1= log( (pcm +sqrt(pm[0]*pm[0]+pcm*pcm))/(e1+p) );
-       REAL y2=-log( (pcm +sqrt(pm[1]*pm[1]+pcm*pcm))/(e2+p) );
-       if(pm[0]>0) { REAL y=  log( pm[0]/(e1+p)); if(y2<y) y2=y; }
-       if(pm[1]>0) { REAL y= -log( pm[1]/(e2+p)); if(y1>y) y1=y; }
+       REAL s=pm[0]+pm[1], d=pm[0]-pm[1], p=Sqrt((pm[2]-s)*(pm[2]+ s)*(pm[2]-d)*(pm[2]+d))/(2*pm[2]);
+       REAL e1=Sqrt(p*p+pm[0]*pm[0]), e2=Sqrt(p*p+pm[1]*pm[1]);
+       REAL y1= Log( (pcm +Sqrt(pm[0]*pm[0]+pcm*pcm))/(e1+p) );
+       REAL y2=-Log( (pcm +Sqrt(pm[1]*pm[1]+pcm*pcm))/(e2+p) );
+       if(pm[0]>0) { REAL y=  Log( pm[0]/(e1+p)); if(y2<y) y2=y; }
+       if(pm[1]>0) { REAL y= -Log( pm[1]/(e2+p)); if(y1>y) y1=y; }
        for(i=0;i<12;i++)pvect[i]=0;
        pvect[0]=e1; pvect[3]=p;
        pvect[4]=e2; pvect[7]=-p;
@@ -236,7 +236,7 @@ int mkmom(double*x,double*tfact,double*xp1,double*xp2,REAL*pvect)
             xtilda=(stilda-sbot)/(stop-sbot);
 
 	    if (sf_num[0] && sf_num[1]) 
-	    { REAL yy = log(1/xtilda); 
+	    { REAL yy = Log(1/xtilda); 
 		xx = x[nx++];
 		if (beta[0] < 1 && beta[1] < 1) 
 		{
@@ -282,15 +282,15 @@ int mkmom(double*x,double*tfact,double*xp1,double*xp2,REAL*pvect)
 		x2 = exp(-y2);
                 ytilda=(y2-y1)/2;
 	    } else if (sf_num[0]) 
-	    {   REAL e2=sqrt(pm[1]*pm[1]+pcm*pcm);
+	    {   REAL e2=Sqrt(pm[1]*pm[1]+pcm*pcm);
 		x1 = xtilda;
 		x2 = 1;
-                ytilda=0.5*log((e2+(2*x1-1)*pcm)/(e2+pcm));
+                ytilda=0.5*Log((e2+(2*x1-1)*pcm)/(e2+pcm));
 	    } else 
-	    {   REAL e1=sqrt(pm[0]*pm[0]+pcm*pcm);
+	    {   REAL e1=Sqrt(pm[0]*pm[0]+pcm*pcm);
 		x1 = 1;
 		x2 = xtilda;
-                ytilda=-0.5*log((e1+(2*x2-1)*pcm)/(e1+pcm));
+                ytilda=-0.5*Log((e1+(2*x2-1)*pcm)/(e1+pcm));
 	    }
 	} else 
 	{
@@ -299,7 +299,7 @@ int mkmom(double*x,double*tfact,double*xp1,double*xp2,REAL*pvect)
 	    stilda = sqrt_S*sqrt_S;
             ytilda=0;
 	}
-        rstilda = sqrt(stilda);
+        rstilda = Sqrt(stilda);
         pcmtilda=cmfun(rstilda,pm[0],pm[1]);
 	pIn[0][3]=pcmtilda;
 	pIn[1][3]=-pcmtilda;
@@ -339,7 +339,7 @@ int mkmom(double*x,double*tfact,double*xp1,double*xp2,REAL*pvect)
 		
 		d__1 = summas[i][k];
 		smin = d__1 * d__1;
-//printf("smin=%E smax=%E\n", smin,smax);
+
 		if (nmscut[i][k]) rancor_(&smin, &smax,0., 1., nmscut[i][k]);
 		
 		if (smin >= smax)  {*tfact = 0; return 0;}
@@ -348,14 +348,13 @@ int mkmom(double*x,double*tfact,double*xp1,double*xp2,REAL*pvect)
 		{
 		    nsing = 0;
 		    getreg_(&nsing, singar, 0., 1.,nmsreg[i][k]);
-//printf("getreg smin=%E smax=%e   1\n",smin,smax);
 		    regfun_(2,nsing,singar,smin,smax,xx,&sqmass,&fct);
 		} else
 		{
 		    sqmass = xx * smax + (1 - xx) * smin;
 		    fct = smax - smin;
 		} 
-		amass[i][k] = sqrt(sqmass);
+		amass[i][k] = Sqrt(sqmass);
 		*tfact *= fct;
 	    }
 	    else amass[i][k]= summas[i][k];
@@ -409,7 +408,6 @@ int mkmom(double*x,double*tfact,double*xp1,double*xp2,REAL*pvect)
 	    int ncT=sph_inf[i][ns___].tcscut[k];
 	    d__1 = ((k << 1) - 1) / hdif;
             getreg_(&nsing,singar,hsum[k],d__1,sph_inf[i][ns___].ncsreg[k]);
-//printf("getreg_2\n");            
             if(ncM) rancor_(&cosmin,&cosmax,hsum[k],d__1,ncM);
             if(ncT) rancor_t(&cosmax,hsum[k],d__1,Emax[k], pm[sph_inf[i][ns___].lvpole[0]-1],pcmtilda, 
                             amass[i][k], invcut_1[ncT-1].cvmin );
@@ -434,7 +432,6 @@ int mkmom(double*x,double*tfact,double*xp1,double*xp2,REAL*pvect)
                 int ncT=sph_inf[i][ns].tcscut[k];
 		d__1 = ((k << 1) - 1) / hdif;
 		getreg_(&nsing,singar,hsum[k],d__1,sph_inf[i][ns].ncsreg[k]);
-//printf("getreg_3\n");		
 		if(ncM) rancor_(&cosmin,&cosmax,hsum[k],d__1,ncM);
                 if(ncT) rancor_t(&cosmax,hsum[k],d__1,Emax[k], pm[sph_inf[i][ns___].lvpole[0]-1],pcmtilda, 
                             amass[i][k], invcut_1[ncT-1].cvmin );
@@ -542,14 +539,14 @@ int imkmom(double P1, double P2)
        ssmin*=ssmin;      
  
        if( sf_num[0] && sf_num[1] ) {sbot=0;stop=4*pcm*pcm;}
-       else if(sf_num[0]){sbot=m2*m2; stop=sbot+2*pcm*(pcm+sqrt(pcm*pcm+sbot));}
-       else if(sf_num[1]){sbot=m1*m1; stop=sbot+2*pcm*(pcm+sqrt(pcm*pcm+sbot));} 
+       else if(sf_num[0]){sbot=m2*m2; stop=sbot+2*pcm*(pcm+Sqrt(pcm*pcm+sbot));}
+       else if(sf_num[1]){sbot=m1*m1; stop=sbot+2*pcm*(pcm+Sqrt(pcm*pcm+sbot));} 
        else  stop = sqrt_S*sqrt_S;
        ssmax=stop;
     } else 
     {   REAL m1=pm[0];
 
-//        rapidity=log((P1+sqrt(P1*P1+m1*m1))/m1 ) ;
+//        rapidity=Log((P1+Sqrt(P1*P1+m1*m1))/m1 ) ;
         rapidity=0;  
     }
     for(i = 0; i < nout1; ++i) 
