@@ -26,11 +26,14 @@
 #include"VandP.h"
 #include"dynamic_cs.h"
 
-#define NITEMS 19
+#define NITEMS 20
 char *p_names[20];
 int   p_codes[20];
 static int rdErr;
 
+static int w_SLHA(FILE *f) { fprintf(f," %d",useSLHAwidth);  return 0; }
+static int r_SLHA(FILE *f) { fscanf(f," %d", &useSLHAwidth); return 0;  }
+
 static int writeIntegral(FILE *f)
 {
   fprintf(f," %.17E %.17E %.17E %d %d %ld %d %d", integral.s0,integral.s1,integral.s2,
@@ -92,8 +95,9 @@ static int w_widths(FILE *mode)
    fprintf(mode,"BW range    %f\n"
                 "t-channel widths %d\n"
                 "GI trick in s-  %d\n"
-                "GI trick in t-  %d",
-           *BWrange_int,*twidth_int,*gswidth_int,1);
+                "GI trick in t-  %d\n"
+                "useSLHAwidth    %d\n",
+           *BWrange_int,*twidth_int,*gswidth_int,*gtwidth_int,useSLHAwidth);
    return 0;             
 }
 
@@ -101,8 +105,9 @@ static int r_widths(FILE *mode)
 {    fscanf(mode,"BW range    %lf\n"     
                  "t-channel widths %d\n"
                  "GI trick in s-  %d\n"                  
-                 "GI trick in t-  %*d",  
-           BWrange_int,twidth_int,gswidth_int);
+                 "GI trick in t-  %d\n"
+                 "useSLHAwidth    %d\n",   
+           BWrange_int,twidth_int,gswidth_int,gtwidth_int,&useSLHAwidth);
 
      return 0;
 }                                   
@@ -213,6 +218,7 @@ int w_sess__(FILE *mode_)
       {"Physical_Parameters",  w_mdl__},
       {"Breit-Wigner",    w_widths}, 
       {"VVdecays",        w_VVdecays},
+      {"SLHAwidth",       w_SLHA},
       {"alphaQCD",        w_alphaQCD},
       {"QCDscales",       w_Scales},      
       {"Composites",      wrtcomp_},
@@ -259,6 +265,7 @@ int r_sess__(FILE *mode_)
    {"Physical_Parameters",  r_mdl__},
    {"Breit-Wigner",    r_widths},
    {"VVdecays",        r_VVdecays}, 
+   {"SLHAwidth",       r_SLHA},
    {"alphaQCD",        r_alphaQCD},
    {"QCDscales",       r_Scales},          
    {"Composites",      rdrcomp_},
