@@ -13,9 +13,7 @@
 #include "plot.h"
 
 
-static    int logX=0;
-
-
+ static    int logX=0;
 
  static int X1, Y1, X2, Y2;
 
@@ -87,17 +85,22 @@ static void  gminmax(double *f ,double * df,int dim, double *ymin,double*ymax)
    int i;
    if (dim==0) return;
 
-   *ymin=f[0];
-   *ymax=f[0];
-   if(df) { *ymax += df[0]; *ymin -= df[0];}
- 
-   if(df) for(i=1;i<dim;i++)
-   { *ymin=MIN(*ymin, f[i]-df[i]); 
-     *ymax=MAX(*ymax, f[i]+df[i]);
-   } else for(i=1;i<dim;i++)
-   { *ymin=MIN(*ymin, f[i]); 
-     *ymax=MAX(*ymax, f[i]);
-   } 
+   for(i=0;i<dim;i++)  if(isfinite(f[i])) break;
+   
+   *ymin=f[i];
+   *ymax=f[i];
+
+   if(df && isfinite(df[i]) ) { *ymax += df[i]; *ymin -= df[i];}
+   i++;
+   for(;i<dim;i++) if(isfinite(f[i]))
+   { if(df && isfinite(df[i])) 
+     { *ymin=MIN(*ymin, f[i]-df[i]); 
+       *ymax=MAX(*ymax, f[i]+df[i]);
+     } else
+     { *ymin=MIN(*ymin, f[i]); 
+       *ymax=MAX(*ymax, f[i]);
+     }
+   }   
    double z=(*ymax-*ymin)/50;
    *ymax+=z;
 }
@@ -178,7 +181,7 @@ static int colList[]={Black,Blue,Red,Yellow,Magenta, Green,Cyan, Brown,LightGray
 static char*colListTxt[]={"Black","Blue","Red","Yellow","Magenta", "Green","Cyan", "Brown","LightGray",
               "DarkGray", "LightBlue","LightGreen","LightCyan","LightRed","LightMagenta","White"};
 
-static void  gaxes(char* upstr, char* xstr, char*ystr, int N, char**Y)
+static void  gaxes(char* upstr, char* xstr, int N, char**Y)
 {
 
    double  xmax,xmin,ymax,ymin,aa,step; 
@@ -286,17 +289,13 @@ static void  gaxes(char* upstr, char* xstr, char*ystr, int N, char**Y)
      {  tg_settextjustify(RightText,TopText); 
         tg_outtextxy(X2,Y1 + hash + th ,xstr);
      }else
-     {  tg_settextjustify(LeftText,BottomText);
-        tg_outtextxy(X1-6*tw,Y2-th/2+1 ,ystr);
-        if(Y)
-        {
-          goto_xy(15,3);   
-          for(i=0;i<N;i++) if(strlen(Y[i])>0)   
-          {  scrcolor(colList[i],bkcolor);
-             print("%s",Y[i]);
-             if(i<N-1) print("; ");
-          }       
-        }
+     {  tg_settextjustify(LeftText,CenterText);
+        goto_xy(10,2);
+        for(i=0;i<N;i++)   
+        {  scrcolor(colList[i],bkcolor);
+           print("%s",Y[i]);
+           if(i<N-1) print("; ");
+        }       
      }
    }
      
@@ -319,22 +318,25 @@ static void plot_curve(double xMin,double xMax,int dim, double *f)
       } else
       {  x =dscx(xMin+(i-0.5)*step);
          xx=dscx(xMin+(i+0.5)*step);
-      }    
-      y =dscy(f[i-1]);
-      yy=dscy(f[i]);
+      } 
+      if(isfinite(f[i-1]) && isfinite(f[i]))
+      {   
+        y =dscy(f[i-1]);
+        yy=dscy(f[i]);
       
-      if ( yy < y) 
-      { double z;
-        z=yy;yy=y;y=z;
-        z=xx;xx=x;x=z;
-      }
+        if ( yy < y) 
+        { double z;
+          z=yy;yy=y;y=z;
+          z=xx;xx=x;x=z;
+        }
    
-      if (yy>ymin &&  y<ymax)         
-      {
-        if(yy>ymax){ xx= xx-((xx-x)*(yy-ymax))/(yy-y); yy=ymax;}
-        if(y<ymin) {  x=  x-((x-xx)*(y -ymin))/(y-yy); y=ymin;}
-        tg_line((int)x,(int)y,(int)xx,(int)yy);
-      }
+        if (yy>ymin &&  y<ymax)         
+        {
+          if(yy>ymax){ xx= xx-((xx-x)*(yy-ymax))/(yy-y); yy=ymax;}
+          if(y<ymin) {  x=  x-((x-xx)*(y -ymin))/(y-yy); y=ymin;}
+          tg_line((int)x,(int)y,(int)xx,(int)yy);
+        }
+      }  
    }
       
 }
@@ -435,7 +437,7 @@ static void plot_hist(double xMin,double xMax,int dim, double *f,double *df)
 
 
 static int writetable1(char * filename, double xMin,double xMax, double yMin, double yMax,
-     char*x_str, char*upstr, char*y_str,
+     char*x_str,char*upstr, 
  int N, int*Dim, double**f,double**df,char**Y)  
 { 
    FILE *     outfile;
@@ -450,23 +452,19 @@ static int writetable1(char * filename, double xMin,double xMax, double yMin, do
    for(i=0;i<N;i++) if(maxDim<Dim[i]) maxDim=Dim[i];
    outfile=fopen(filename,"w");
    if(outfile==NULL) return 1;
-   fprintf(outfile,"#type  1 %% 1d plot\n");
    fprintf(outfile,"#title %s\n",upstr);
-   fprintf(outfile,"#xName %s\n",x_str);
-   fprintf(outfile,"#xMin %E\n",xMin);
-   fprintf(outfile,"#xMax %E\n",xMax);
-   
-   fprintf(outfile,"#xScale %d\n",logX);
-   fprintf(outfile,"#yName %s\n",y_str);
-   fprintf(outfile,"#dataList ");
+   fprintf(outfile,"#yName ");
    for(k=0;k<N;k++)
    {  fprintf(outfile,"%s",Y[k]);
       if(df[k])  fprintf(outfile,"{h}"); else fprintf(outfile,"{c} ");
    } 
-
    fprintf(outfile,"\n");
+   fprintf(outfile,"#xName %s\n",x_str);
+   fprintf(outfile,"#xMin %E\n",xMin);
+   fprintf(outfile,"#xMax %E\n",xMax);
    fprintf(outfile,"#xDim "); for(i=0;i<N;i++) fprintf(outfile," %d",Dim[i]); fprintf(outfile,"\n");
-
+   
+   fprintf(outfile,"#xScale %d\n",logX);
        
    fprintf(outfile,"#---   starting of data ---\n#");
    for(k=0;k<N;k++) 
@@ -495,7 +493,7 @@ static int writetable1(char * filename, double xMin,double xMax, double yMin, do
 }
 
 static void  writeGNU(char*fname, double xMin,double xMax, double yMin, double yMax, 
-     char*x_str, char*y_str,char*upstr,  int N, int*Dim, char* type,char**Y)  
+     char*x_str,char*upstr,  int N, int*Dim, char* type,char**Y)  
 {  char       filename[100], buff[STRSIZ],command[100];
    FILE *     outfile;
    int        i,k;
@@ -514,7 +512,7 @@ static void  writeGNU(char*fname, double xMin,double xMax, double yMin, double y
    fprintf(outfile,"# set terminal latex \n");
    fprintf(outfile,"# set title  '%s'\n",upstr);
    fprintf(outfile," set xlabel '%s'\n",x_str);
-   if(strlen(y_str)>0) fprintf(outfile," set ylabel '%s'\n",y_str);
+   if(N==1) fprintf(outfile," set ylabel '%s'\n",Y[0]);
    fprintf(outfile," xMin=%E\n",xMin);
    fprintf(outfile," xMax=%E\n",xMax);
    fprintf(outfile," yMin=%E\n",yMin);
@@ -557,7 +555,7 @@ static void  writeGNU(char*fname, double xMin,double xMax, double yMin, double y
 
 
 static void  writePAW(char *fname,  double xMin,double xMax, double yMin, double yMax,
-     char*x_str, char*y_str,char*upstr, 
+     char*x_str,char*upstr, 
  int N, int*Dim, char*type,char**Y)  
 {  char       filename[100], buff[STRSIZ],command[100];
    FILE *     outfile;
@@ -661,7 +659,7 @@ static void  writePAW(char *fname,  double xMin,double xMax, double yMin, double
    }
           
    fprintf(outfile," set txci 1 \n" );
-   if(strlen(y_str)>0) fprintf(outfile," atitle  '%s' '%s'\n",x_str,y_str);
+   if(N==1) fprintf(outfile," atitle  '%s' '%s'\n",x_str,Y[0]);
    else     fprintf(outfile," atitle  '%s'\n",x_str);
    fprintf(outfile," pic/print  %s.eps\n",fname); 
 
@@ -672,7 +670,7 @@ static void  writePAW(char *fname,  double xMin,double xMax, double yMin, double
 
 
 static void  writeROOT(char *fname,  double xMin,double xMax, double yMin, double yMax, 
-     char*x_str, char* y_str, char*upstr,  int N, int*Dim, char*type,char**Y)  
+     char*x_str,char*upstr, int N, int*Dim, char*type,char**Y)  
 {  char       filename[100],basename[100], buff[STRSIZ];
    FILE *     outfile;
    int        i,k;
@@ -703,7 +701,7 @@ fprintf(outfile,
    if(i<0) i=0;
    fprintf(outfile,"void %s(void)\n{\n",basename+i);
    
-   fprintf(outfile," TCanvas *Can = new TCanvas(\"c\",\"%s\",200,10,700,400);\n",upstr);
+   fprintf(outfile," TCanvas *Can = new TCanvas(\"c\",\"%s\",200,10,600,400);\n",upstr);
    fprintf(outfile," double xMin=%E, xMax=%E, yMin=%E, yMax=%E;\n",xMin,xMax,yMin,yMax);
    fprintf(outfile," char buff[2000];\n");
    fprintf(outfile," double "); 
@@ -731,7 +729,7 @@ fprintf(outfile,
        
    fprintf(outfile," TH1F *hr = Can->DrawFrame(xMin,yMin,xMax,yMax);\n");
    fprintf(outfile," hr->SetXTitle(\"%s\");\n",x_str);   
-   if(strlen(y_str)>0)fprintf(outfile," hr->SetYTitle(\"%s\");\n",y_str);   
+   if(N==1) fprintf(outfile," hr->SetYTitle(\"%s\");\n",Y[0]);   
 
    int maxDim=0;
    for(k=0;k<N;k++) if(Dim[k]>maxDim) maxDim=Dim[k];
@@ -762,7 +760,7 @@ fprintf(outfile,
    fprintf(outfile, " TLatex ltx;\n");
    fprintf(outfile, " ltx.SetTextFont(42);\n");
    fprintf(outfile, " ltx.SetTextSize(0.04);\n");
-           
+   fprintf(outfile, "int i0,i1;\n");        
    for(k=0;k<N;k++)
    { if(type[k]=='h') 
      {  fprintf(outfile,"   TGraphErrors *gr%d =new TGraphErrors(%d,X%d,Y%d,dX%d,dY%d);\n",k,Dim[k],k,k,k,k);
@@ -770,7 +768,9 @@ fprintf(outfile,
         fprintf(outfile,"   gr%d->Draw(\"P\");\n",k);
      } else 
      {   
-       fprintf(outfile, "   TGraph *gr%d = new TGraph (%d,X%d,Y%d);\n",k,Dim[k],k,k); 
+       fprintf(outfile, "   for(i0=0;!isfinite(Y%d[i0]);i0++);\n",k);
+       fprintf(outfile, "   for(i1=%d;!isfinite(Y%d[i1]);i1--);\n",Dim[k]-1, k); 
+       fprintf(outfile, "   TGraph *gr%d = new TGraph (1+i1-i0,X%d+i0,Y%d+i0);\n",k,k,k); 
        fprintf(outfile, "   gr%d->SetLineColor(%d);\n",k,k+1);
        if(type[k]=='l') fprintf(outfile, "   gr%d->Draw(\"L\");\n",k);
        else fprintf(outfile, "   gr%d->Draw(\"C\");\n",k);
@@ -798,7 +798,7 @@ fprintf(outfile,
 }
 
 static void  writePython(char *fname,  double xMin,double xMax, double yMin, double yMax,
-     char*x_str, char*y_str, char*upstr, int N, int*Dim, char*type, char**Y)  
+     char*x_str, char*upstr, int N, int*Dim, char*type, char**Y)  
 {  char       filename[100],basename[100], buff[STRSIZ];
    FILE *     outfile;
    int        i,k;
@@ -834,7 +834,7 @@ static void  writePython(char *fname,  double xMin,double xMax, double yMin, dou
 
    fprintf(outfile,"plt.title('%s')\n", upstr);
    fprintf(outfile,"plt.xlabel('%s',fontsize=16)\n", x_str);
-   if(strlen(y_str)>0) fprintf(outfile,"plt.ylabel('%s',fontsize=16)\n", y_str);
+   if(N==1) fprintf(outfile,"plt.ylabel('%s',fontsize=16)\n", Y[0]);
    if(logX) fprintf(outfile,"plt.xscale('log')\n");    else fprintf(outfile,"plt.xscale('linear')\n"); 
    if(logY)fprintf(outfile,"plt.yscale('log')\n"); else fprintf(outfile,"plt.yscale('linear')\n");
    fprintf(outfile,"xmin=%E\n",xMin);
@@ -842,7 +842,7 @@ static void  writePython(char *fname,  double xMin,double xMax, double yMin, dou
    fprintf(outfile,"plt.xlim(xmin,xmax)\n");
    fprintf(outfile,"plt.ylim(%E,%E)\n",yMin,yMax);
    for(k=0;k<N;k++) if(type[k]=='s') break;
-   if(k!=N) // interpolation is needed
+   if(k!=N) // interpalation is needed
    { if(logX)
      { fprintf(outfile,"li=np.linspace(log(xmin), log(xmax),300)\n");
        fprintf(outfile,"xi=np.exp(li)\n");
@@ -920,6 +920,102 @@ static void  writePython(char *fname,  double xMin,double xMax, double yMin, dou
    fprintf(outfile,"plt.savefig('%s.pdf')\n", basename);
    fprintf(outfile,"plt.show()\n"); 
         
+#ifdef UseDeleted 
+    
+   for(i=strlen(basename)-1; i>=0 && basename[i]!='/';i--);
+   if(i<0) i=0;
+   fprintf(outfile,"void %s(void)\n{\n",basename+i);
+   
+   fprintf(outfile," TCanvas *Can = new TCanvas(\"c\",\"%s\",200,10,600,400);\n",upstr);
+   fprintf(outfile," double xMin=%E, xMax=%E, yMin=%E, yMax=%E;\n",xMin,xMax,yMin,yMax);
+   fprintf(outfile," char buff[2000];\n");
+   fprintf(outfile," double "); 
+   for(k=0;k<N;k++){ fprintf(outfile," X%d[%d],dX%d[%d]",k,Dim[k],k,Dim[k]); 
+                     if(k<N-1) fprintf(outfile,","); else  fprintf(outfile,";\n");
+                   }           
+   if(logX)
+   { 
+        fprintf(outfile," Can->SetLogx();\n");
+        for(k=0;k<N;k++) fprintf(outfile," for(int i=0;i<%d;i++){ X%d[i]=xMin*pow(xMax/xMin,(i+0.5)/%d);dX%d[i]=X%d[i]*(pow(xMax/xMin,0.333/%d)-1);} \n", Dim[k],k,Dim[k],k,k,Dim[k]);    
+   } 
+   else for(k=0;k<N;k++) fprintf(outfile," for(int i=0;i<%d;i++){ X%d[i]=xMin+(i+0.5)*(xMax-xMin)/%d; dX%d[i]=(xMax-xMin)/3./%d;}\n", Dim[k],k,Dim[k],k,Dim[k]);
+         
+
+   if(logX)fprintf(outfile," double Xtext = xMin*pow(xMax/xMin,0.3);\n");  
+   else    fprintf(outfile," double Xtext = xMin+0.3*(xMax-xMin);\n");  
+   fprintf(outfile," double Ytext= yMax;\n");
+
+   if(logY)   
+   {
+     fprintf(outfile," Can->SetLogy();\n");
+     fprintf(outfile," double dYtext=pow(yMax/yMin,0.055);\n");
+   } else fprintf(outfile," double dYtext= (yMax-yMin)/15;\n");
+   
+       
+   fprintf(outfile," TH1F *hr = Can->DrawFrame(xMin,yMin,xMax,yMax);\n");
+   fprintf(outfile," hr->SetXTitle(\"%s\");\n",x_str);   
+   if(N==1) fprintf(outfile," hr->SetYTitle(\"%s\");\n",Y[0]);   
+
+   int maxDim=0;
+   for(k=0;k<N;k++) if(Dim[k]>maxDim) maxDim=Dim[k];
+   
+   for(k=0;k<N;k++)
+   {  
+     fprintf(outfile," double  Y%d[%d];\n",k,maxDim);
+     sprintf(format+strlen(format)," %%lf");
+     sprintf(read+strlen(read)," ,Y%d+i",k);
+     if(type[k]=='h')
+     {  fprintf(outfile," double  dY%d[%d];\n",k,maxDim);  
+        sprintf(format+strlen(format)," %%lf");
+        sprintf(read+strlen(read)," ,dY%d+i",k);
+     }
+   }
+   
+   fprintf(outfile, " FILE*f=fopen(\"%s\",\"r\");\n",fname);
+   fprintf(outfile, " for(int i=0;i<%d;)\n {\n",maxDim);
+   fprintf(outfile, "  fscanf(f,\"%%[^\\n]%%*c\",buff);\n");
+   fprintf(outfile, "  if(buff[0]!='#') {");
+   fprintf(outfile, "  sscanf(buff,\"%s\" %s); i++;", format, read);
+   fprintf(outfile, "    }\n }\n");
+   fprintf(outfile, " fclose(f);\n");
+
+//   fprintf(outfile, " double dX[%d];\n",dim);
+//   fprintf(outfile, " for(int i=0;i<%d;i++) dX[i]=(xMax-xMin)/%d/3.;\n",dim,dim);
+
+   fprintf(outfile, " TLatex ltx;\n");
+   fprintf(outfile, " ltx.SetTextFont(42);\n");
+   fprintf(outfile, " ltx.SetTextSize(0.04);\n");
+           
+   for(k=0;k<N;k++)
+   { if(type[k]=='h') 
+     {  fprintf(outfile,"   TGraphErrors *gr%d =new TGraphErrors(%d,X%d,Y%d,dX%d,dY%d);\n",k,Dim[k],k,k,k,k);
+        fprintf(outfile,"   gr%d->SetLineColor(%d);\n",k,k+1); 
+        fprintf(outfile,"   gr%d->Draw(\"P\");\n",k);
+     } else 
+     {   
+       fprintf(outfile, "   TGraph *gr%d = new TGraph (%d,X%d,Y%d);\n",k,Dim[k],k,k); 
+       fprintf(outfile, "   gr%d->SetLineColor(%d);\n",k,k+1);
+       if(type[k]=='l') fprintf(outfile, "   gr%d->Draw(\"L\");\n",k);
+       else fprintf(outfile, "   gr%d->Draw(\"C\");\n",k);
+     }
+     if(N>1 && Y[k][0])
+     {
+        if(logY) fprintf(outfile,"   Ytext/=dYtext;\n"); else  fprintf(outfile,"  Ytext-=dYtext;\n");
+/*
+        fprintf(outfile,"  TText *t%d = new TText(Xtext,Ytext,\"%s\");\n",k,Y[k]);
+        fprintf(outfile,"  t%d->SetTextColor(%d);\n",k,k+1);
+        fprintf(outfile,"  t%d->SetTextFont(42);\n",k);
+        fprintf(outfile,"  t%d->SetTextSize(0.03);\n",k);
+        fprintf(outfile,"  t%d->Draw();\n",k);
+*/        
+        fprintf(outfile,"    ltx.SetTextColor(%d);\n",k+1);
+        fprintf(outfile,"    ltx.DrawLatex(Xtext,Ytext,\"%s\");\n",Y[k]);         
+     } 
+   }  
+   fprintf(outfile," Can->Print(\"%s.pdf\");\n",basename);
+   
+   fprintf(outfile,"}\n");
+#endif   
    fclose(outfile);
    
    messanykey(10,12,filename);
@@ -1006,7 +1102,6 @@ double * f, double *df, char*  upstr,  char*  x_str, char*  y_str)
    fprintf(outfile,"#yMin %E\n",yMin);
    fprintf(outfile,"#yMax %E\n",yMax);
    fprintf(outfile,"#yDim %d\n",dimY);
-   fprintf(outfile,"%dataList {h}\n");
      
    fprintf(outfile,"#---   starting of data ---\n");
    fprintf(outfile,"#--- F ---    --- dF ---\n");
@@ -1217,8 +1312,8 @@ double * f, double *df, char*  upstr,  char*  x_str, char*  y_str)
 
 
    
-int  plot_Nar( char*file, char*  title,char*xName, double xMin, double xMax, int xScale,
-             char * yName,  int N,char**Y, int*Dim, double **f,double**ff)
+int  plot_Nar( char*file, char*  title, char*xName, double xMin, double xMax,  int xScale,
+               int N, int*Dim, double **f,double**ff,char**Y)
 {   
   void *     prtscr;  
   int i,k,nCol0,nRow0,key;
@@ -1226,13 +1321,13 @@ int  plot_Nar( char*file, char*  title,char*xName, double xMin, double xMax, int
   char        f_name[STRSIZ], menustr[STRSIZ], buff[STRSIZ];
   char * type=malloc(sizeof(char)*N);
   static int mouseXY=0;
-
   
+/*
   for(i=0;i<N;i++) 
   {            for(k=0;k<Dim[i];k++) if(!isfinite( f[i][k])) return 1;
      if(ff[i]) for(k=0;k<Dim[i];k++) if(!isfinite(ff[i][k])) return 1; 
   }
-  
+*/  
 #define MESS "Esc - exit; Mouse - position; Other keys - menu"
    get_text(1,1,maxCol(),maxRow(),&prtscr);
 
@@ -1251,14 +1346,14 @@ int  plot_Nar( char*file, char*  title,char*xName, double xMin, double xMax, int
    ymax=grafminmax.ymax;
    
    logX=xScale;
-   logY=0;//(ymin >0 && grafminmax.ymax/grafminmax.ymin >10);   
+   logY=(ymin >0 && grafminmax.ymax/grafminmax.ymin >100);   
    k = 0;      
 REDRAW:
    nCol0=maxCol();
    nRow0=maxRow();
    clr_scr(fgcolor,bkcolor);
    
-   gaxes(title,xName,yName,N,Y);
+   gaxes(title,xName,N,Y);
 
    for(i=0;i<N;i++)
    {   fColor=colList[i];
@@ -1380,7 +1475,7 @@ REDRAW:
                 correctStr(10,17,"File name: ",baseF,29,1);
                 trim(baseF);
                 err=writetable1(baseF,xMin,xMax,grafminmax.ymin,grafminmax.ymax,
-                    xName,title, yName,  N, Dim, f,ff,Y);
+                    xName,title,N, Dim, f,ff,Y);
                 if(err) 
                 {         
                    sprintf(buff,"Can not create file '%s'\n",baseF);
@@ -1403,15 +1498,15 @@ contin:
              {  menu1(nCol0-15, 6, "For Package",fileMenu,"n_graph_*",NULL,&m);             
                 switch(m)        
                 {  case 1: writeROOT(baseF,xMin,xMax,grafminmax.ymin,grafminmax.ymax,
-                                    xName, yName,title,N,Dim,type,Y);
+                                    xName,title,N,Dim,type,Y);
                    break;
                    case 2: writePAW(baseF,xMin,xMax,grafminmax.ymin,grafminmax.ymax,
-                                    xName,yName,title,N,Dim,type,Y);
+                                    xName,title,N,Dim,type,Y);
                    break;                  
                    case 3: writeGNU(baseF,xMin,xMax,grafminmax.ymin,grafminmax.ymax,           
-                                    xName,yName,title,N,Dim,type,Y);
+                                    xName,title,N,Dim,type,Y);
                    case 4: writePython(baseF,xMin,xMax,grafminmax.ymin,grafminmax.ymax,
-                                    xName,yName,title,N,Dim,type,Y);
+                                    xName,title,N,Dim,type,Y);
                                                        
                    break;
 //                   case 4:
@@ -1448,7 +1543,7 @@ exi:
    return 0;
 }
 
-int  plot_N(char*title, char*  xName, double xMin, double xMax, int xScale, char *yName, int N,...)
+int  plot_N(char*title, char*  xName,  double xMin, double xMax,  int xScale, int N,...)
 { int err, k,i;
                                                                
   double **f; double**ff; char**Y;
@@ -1467,15 +1562,14 @@ int  plot_N(char*title, char*  xName, double xMin, double xMax, int xScale, char
    va_start(ap,N);
    
    for(i=0;i<N;i++) 
-   { 
-     Y[i]=va_arg(ap,char*);
-     Dim[i]=va_arg(ap,int); 
+   { Dim[i]=va_arg(ap,int); 
      f[i]=va_arg(ap,double*);
      ff[i]=va_arg(ap,double*);
+     Y[i]=va_arg(ap,char*);
    }  
    va_end(ap);
 
-   err=plot_Nar(NULL,title,xName,xMin,xMax,xScale,yName, N,Y, Dim,f,ff);
+   err=plot_Nar(NULL,title,xName,xMin,xMax,xScale, N,Dim,f,ff,Y);
 
    free(f);free(ff);free(Y),free(Dim);
    return err;
@@ -1483,9 +1577,7 @@ int  plot_N(char*title, char*  xName, double xMin, double xMax, int xScale, char
 
 void   plot_1(double xMin, double xMax, int dim,
                     double *f, double *ff,char* title, char* xstr, char* ystr)
-{ char* zero=""; 
-  plot_Nar(NULL,title,xstr, xMin, xMax,0, ystr, 1, &zero, &dim,&f,&ff); 
-} 
+{  plot_Nar(NULL,title,xstr,xMin, xMax,0, 1,&dim,&f,&ff, &ystr); } 
                     
 
 void plot_2D(double hMin1,double hMax1,int nBin1,double hMin2,double hMax2,int nBin2,
@@ -1523,7 +1615,7 @@ REDRAW:
    nRow0=maxRow();
    clr_scr(fgcolor,bkcolor);
 
-   gaxes(upstr,xstr,ystr,1,NULL);
+   gaxes(upstr,xstr,1,&ystr);
  
    { int i,j;
      for(i=0;i<nBin1;i++) for(j=0;j<nBin2;j++)
