@@ -7,7 +7,6 @@
 *               25.02.90                *
 *                                       *
 ****************************************/
-#include "tptcmac.h"
 #include "physics.h"
 #include "chep_crt.h"
 #include "diagrams.h"
@@ -86,7 +85,7 @@ typedef int interscreen[koder][yend + ystep];
 typedef struct spool 
    { 
       pnt          add; 
-      char         stn[81]; 
+      char         stn[100]; 
    }  spool;
 
 #undef pnt
@@ -97,8 +96,6 @@ typedef spool* pnt;
 
 static  dscreen    * res;          /* from diaprin */
 static  int      hcontr;       /* from diaprin */
-static  int         isect, jsect; /* from isector */
-static  int      ssect;        /* from isector */
 static  int      left;         /* from diaprt  */
 static  dscreen      resl, resr;   /* from diaprt  */
 static  interscreen  is;           /* from diaprt  */
@@ -121,21 +118,11 @@ static void cr(int n,int x,int y,int ivr,int slt)
 }   /* The end of Cr's body */
 
 
-static char * cmp(char* nm)
-{int         i;
- static char  n[6];
-
-   for (i = 0; (nm[i] != '\0') && (nm[i] != chsp); i++)
-      n[i] = nm[i];
-   n[i] = '\0';
-   return n; 
-} 
-
 
 static void hline(int xs,int xe,int y,int ivr,int slt)
 {int    linech, arrow; 
  int i, j, k, l; 
- char    nm[6]; 
+ char    nm[P_NAME_SIZE]; 
 
    k = hcontr ? (xs + xe) / 2 : res->mhor - (xstep / 2) + 1; 
    if (y > res->mxy) res->mxy = y;
@@ -147,7 +134,7 @@ static void hline(int xs,int xe,int y,int ivr,int slt)
       arrow = l > prtclbase[l-1].anti ? '<' : '>'; 
       if (!(((IN_PRTCL|OUT_PRTCL) & with1->prop) || l < prtclbase[l-1].anti)) 
          l = prtclbase[l-1].anti; 
-      strcpy(nm,cmp(prtclbase[l-1].name)); 
+      strcpy(nm,prtclbase[l-1].name); 
       l = strlen(nm); 
       for (i = xs; i <= xe; i++)
          res->scr[i-1][y-1] = linech; 
@@ -157,8 +144,8 @@ static void hline(int xs,int xe,int y,int ivr,int slt)
          for (i = 1; i <= l; i++)  res->scr[i + j-1][y - 1-1] = nm[i-1]; 
          if (((IN_PRTCL|OUT_PRTCL) & with1->prop)  || debug) 
          { 
-            if ((left ? TRUE : FALSE) == 
-                (with1->moment > 0 ? TRUE : FALSE)) 
+            if ((left ? 1 : 0) == 
+                (with1->moment > 0 ? 1 : 0)) 
                res->scr[k - 1-1][y + 1-1] = '-'; 
             res->scr[k-1][y + 1-1] = chp; 
             res->scr[k + 1-1][y + 1-1] = 
@@ -178,8 +165,8 @@ static void hline(int xs,int xe,int y,int ivr,int slt)
          for (i = 1; i <= l; i++) 
             res->scr[j - i-1][y - 1-1] = nm[i-1]; 
          if (((IN_PRTCL|OUT_PRTCL) & with1->prop) || debug) 
-         {  if ((left ? TRUE : FALSE) == 
-                (with1->moment > 0 ? TRUE : FALSE)) 
+         {  if ((left ? 1 : 0) == 
+                (with1->moment > 0 ? 1 : 0)) 
                res->scr[k + 1-1][y + 1-1] = '-'; 
             res->scr[k-1][y + 1-1] = chp; 
             res->scr[k - 1-1][y + 1-1]        = 
@@ -202,7 +189,7 @@ static void hline(int xs,int xe,int y,int ivr,int slt)
 static void vline(int x,int ys,int ye,int ivr,int slt,  int txt) 
 {int     linech /*, arrow */; 
  int  i, j, k, l; 
- char     nm[6]; 
+ char     nm[P_NAME_SIZE]; 
 
    if (ys > ye) 
    {  --(ys);
@@ -222,7 +209,7 @@ static void vline(int x,int ys,int ye,int ivr,int slt,  int txt)
 
       if (!(((IN_PRTCL|OUT_PRTCL)&with1->prop)   ||  l < prtclbase[l-1].anti)) 
          l = prtclbase[l-1].anti; 
-      strcpy(nm,cmp(prtclbase[l-1].name)); 
+      strcpy(nm,prtclbase[l-1].name); 
       l = strlen(nm); 
       if (ye > ys) 
          for (i = ys; i <= ye; i++) res->scr[x-1][i-1] = linech; 
@@ -236,8 +223,8 @@ static void vline(int x,int ys,int ye,int ivr,int slt,  int txt)
             for (i = 1; i <= l; i++) res->scr[i + j-1][k-1] = nm[i-1]; 
             if (debug) 
             { 
-               if ((left ? TRUE : FALSE) == 
-                   (with1->moment > 0 ? TRUE : FALSE)) 
+               if ((left ? 1 : 0) == 
+                   (with1->moment > 0 ? 1 : 0)) 
                { 
                   res->scr[x + 1-1][k-1] = '-'; 
                   j = 2; 
@@ -262,8 +249,8 @@ static void vline(int x,int ys,int ye,int ivr,int slt,  int txt)
             for (i = 1; i <= l; i++) res->scr[j - i-1][k-1] = nm[i-1]; 
             if (debug) 
             { 
-               if ((left ? TRUE : FALSE) == 
-                   (with1->moment > 0) ? TRUE : FALSE) 
+               if ((left ? 1 : 0) == 
+                   (with1->moment > 0) ? 1 : 0) 
                { 
                   res->scr[x - 1-1][k-1] = '-'; 
                   j = 2; 
@@ -308,17 +295,18 @@ static void mline(int xs,int ys,int xe,int ye,
       } 
    } 
          
-   lg = xs == xe ? TRUE : FALSE; 
+   lg = xs == xe ? 1 : 0; 
    if (lg || !hor) 
       vline(xs,ys,ye,ivr,slt,lg); 
    else 
       if ((ys == ye || hor) && xe != xend) 
          hline(xs + 1,xe - 1,ys,ivr,slt); 
    if (ys != ye && !lg) 
+   { 
       if (hor) 
       { 
          cr(3,xe,ys,ivr,slt); 
-         vline(xe,ys,ye,ivr,slt,FALSE); 
+         vline(xe,ys,ye,ivr,slt,0); 
       } 
       else 
       { 
@@ -328,7 +316,8 @@ static void mline(int xs,int ys,int xe,int ye,
             cr(4,xs,ye,ivr,slt); 
          if (xe != xend) 
             hline(xs + 1,xe - 1,ye,ivr,slt); 
-      } 
+      }
+   }    
 }  /* The end of Mline's body */ 
 
 
@@ -362,13 +351,13 @@ static void lot(int* ylo,int* yhi,int ivr,int slt,int hor)
    } 
       
    tp = howin(iv); 
-   flg = TRUE; 
+   flg = 1; 
    tn = diag.valence[iv-1]; 
    if (tp == 0  && (tn == 4 || (hor && tn == 3  && 
        (OUT_PRTCL&diag.vertlist[iv-1][1].prop) && 
        (OUT_PRTCL&diag.vertlist[iv-1][2].prop)))) 
    { 
-      lot(&yl,&yh,iv,tn,TRUE); 
+      lot(&yl,&yh,iv,tn,1); 
       *ylo += yl + yh + 1; 
       --(tn); 
    } 
@@ -378,7 +367,7 @@ static void lot(int* ylo,int* yhi,int ivr,int slt,int hor)
       lot(&yl,&yh,iv,l,flg); 
       if (flg) 
       { 
-         flg = FALSE; 
+         flg = 0; 
          *ylo += yl; 
          *yhi += yh; 
       } 
@@ -387,13 +376,20 @@ static void lot(int* ylo,int* yhi,int ivr,int slt,int hor)
    } 
 }   /* The end of Lot's body */ 
 
+//static int deep=0;
 
 static void painter(int xc,int yc,int ivr,int slt,int hor)
 {int    tp, l, xcnt, ycnt, xx, yy, hh, 
          ylo, yhi, start, ks, kk, pp; 
  int flag; 
+/*
+char buff[10];
+for(l=0;l<deep;l++) buff[l]=' ';
+buff[l]=0; deep++;
 
-   flag = FALSE; 
+printf("New vertex vrt=%d slt=%d \n",ivr,slt);
+*/
+   flag = 0; 
    start = 2; 
    xcnt = xc; 
    ycnt = yc; 
@@ -403,6 +399,9 @@ static void painter(int xc,int yc,int ivr,int slt,int hor)
         diag.valence[ivr-1] - 1   : 
         diag.valence[ivr-1]       ; 
    lot(&ylo,&yhi,ivr,kk,hor); 
+   
+//printf("%s vert=%d  kk=%d hor=%d ylo=%d yhi=%d\n",buff,ivr,kk,hor,ylo,yhi);
+   
    pp = ks == kk - 1 ? kk - 2 : kk - 1; 
    if (tp == 2) 
    { 
@@ -412,8 +411,8 @@ static void painter(int xc,int yc,int ivr,int slt,int hor)
       {  ycnt += ylo * ystep; 
          yc += (ylo - 1) * ystep;
       } 
-      mline(xstart,yc,xcnt,ycnt,ivr,slt,TRUE); 
-      mline(xstart,ycnt,xcnt,ycnt,ivr,ks,TRUE); 
+      mline(xstart,yc,xcnt,ycnt,ivr,slt,1); 
+      mline(xstart,ycnt,xcnt,ycnt,ivr,ks,1); 
    } 
    else 
       if (tp == 1) 
@@ -422,10 +421,11 @@ static void painter(int xc,int yc,int ivr,int slt,int hor)
          if (hor && diag.valence[ivr-1] == 4) 
          { 
             lot(&hh,&yy,ivr,pp,hor); 
+//printf("%s tp=1, ivr=%d pp=%d hh=%d yy=%d\n",buff, ivr,pp,hh,yy);            
             ycnt += (yhi + hh + 1) * ystep; 
             start = 1; 
          } 
-         mline(xstart,ycnt,xcnt,ycnt,ivr,ks,TRUE); 
+         mline(xstart,ycnt,xcnt,ycnt,ivr,ks,1); 
       } 
       else 
          if (diag.valence[ivr-1] == 4) 
@@ -437,6 +437,9 @@ static void painter(int xc,int yc,int ivr,int slt,int hor)
             if (hor && (OUT_PRTCL&diag.vertlist[ivr-1][1].prop) 
                     && (OUT_PRTCL&diag.vertlist[ivr-1][2].prop)) 
                start = 1; 
+
+//printf("%s first start=%d\n",buff,start);
+
    res->scr[xcnt-1][ycnt-1] = vertsign; 
    if (xcnt > res->mhor) 
       res->mhor = xcnt; 
@@ -445,35 +448,47 @@ static void painter(int xc,int yc,int ivr,int slt,int hor)
       if (!(IN_PRTCL & with1->prop)) 
       { 
          if (flag) 
-            lot(&ylo,&yhi,ivr,l,start != 3); 
+{
+//            lot(&ylo,&yhi,ivr,l,start != 3); 
+
+             
+                         lot(&ylo,&yhi,ivr,l,start==2);
+//printf("%s start=%d  vrt=%d l=%d   hor=%d ylo=%d yhi=%d\n",buff, start, ivr,l, start==2, ylo,yhi);  
+}          
          else 
-            flag = TRUE; 
+            flag = 1; 
          xx = (OUT_PRTCL&with1->prop) ? xend : 
               start == 3 ? xcnt : xcnt + xstep; 
          {vertlink *with2 = &with1->nextvert; 
             if (start == 1) 
             { 
-               lot(&hh,&yy,ivr,pp,TRUE); 
-               yy = ycnt - (yhi + hh + 1) * ystep;
-               mline(xcnt,ycnt,xx,yy,with2->vno,with2->edno,FALSE); 
-               if (!(OUT_PRTCL & with1->prop)) 
-                  painter(xx,yy,with2->vno,with2->edno,TRUE); 
+               
+//               lot(&hh,&yy,ivr,pp,1); 
+                 lot(&hh,&yy,ivr,l-1,1);
+//printf("%s statr1 vrt=%d l-1=%d hh=%d yy=%d\n",buff, ivr, l-1,hh,yy);
+               yy = ycnt - (hh +1) * ystep;
+               mline(xcnt,ycnt,xx,yy,with2->vno,with2->edno,0); 
+               if (!(OUT_PRTCL & with1->prop))  painter(xx,yy,with2->vno,with2->edno,1); 
             } 
             else 
                if (start == 2) 
                { 
-                  mline(xcnt,ycnt,xx,ycnt,with2->vno,with2->edno,TRUE); 
-                  if (!(OUT_PRTCL&with1->prop)) 
-                     painter(xx,ycnt,with2->vno,with2->edno,TRUE); 
-                  yy = yhi; 
+                  lot(&hh,&yhi,ivr,l,1);
+                  mline(xcnt,ycnt,xx,ycnt,with2->vno,with2->edno,1); 
+                  if (!(OUT_PRTCL&with1->prop)) painter(xx,ycnt,with2->vno,with2->edno,1); 
+                  yy = yhi;
+//                  yy=ylo; 
                } 
                else 
                { 
-                  yy += ylo + 1; 
+//printf("%s start=? %d yy=%d  ylo=%d\n",buff,start,yy,ylo);
+                  yy += ylo + 1;
+//                    yy+=yhi+1;
+//printf("%s down %d\n",buff,yy);
                   yy = ycnt + yy * ystep; 
-                  mline(xcnt,ycnt,xx,yy,with2->vno,with2->edno,FALSE); 
-                  if (!(OUT_PRTCL&with1->prop)) 
-                     painter(xx,yy,with2->vno,with2->edno,FALSE); 
+                  
+                  mline(xcnt,ycnt,xx,yy,with2->vno,with2->edno,0); 
+                  if (!(OUT_PRTCL&with1->prop)) painter(xx,yy,with2->vno,with2->edno,0); 
                } 
          } 
          ++(start); 
@@ -483,168 +498,29 @@ static void painter(int xc,int yc,int ivr,int slt,int hor)
 
 
 static void diaprin(dscreen* res1)
-{int      i, j; 
+{  int i, j; 
 
    res = res1; 
-   for (i = 1; i <= xend; i++) 
-      for (j = 1; j <= yend; j++) 
-         res->scr[i-1][j-1] = chsp; 
+   for (i = 0; i < xend; i++) for (j = 0; j < yend; j++)  res->scr[i][j] = chsp; 
    res->mver = 0; 
    res->mhor = 0; 
    res->mxy  = 0; 
 
-   hcontr = TRUE; 
-   if (left) 
-      painter(xstart + xstep,ystart,1,1,TRUE); 
-   else 
-      painter(xstart + xstep,ystart,diag.sizel + 1,1,TRUE); 
+   hcontr = 1; 
+   if (left)  painter(xstart + xstep,ystart,1,1,1); 
+        else  painter(xstart + xstep,ystart,diag.sizel + 1,1,1); 
    res->mhor += xstep - 1; 
-   hcontr = FALSE; 
+   hcontr = 0; 
 
-   for (i = 1; i <= res->mver; i++) 
-   {intsect *with1 = &res->ints[i-1]; 
-      hline(with1->xst,res->mhor,with1->y,
-      with1->selfvert,with1->selfslot); 
+// outgoing particles 
+   for (i = 0; i < res->mver; i++)     
+   {  intsect *with1 = &res->ints[i]; 
+      hline(with1->xst,res->mhor,with1->y,with1->selfvert,with1->selfslot); 
    }
 
 }   /* The end of Diaprin's body */ 
 
 
-static int lh(int y)
-{   
-   if (is[jsect-1][y-1] == chsp) 
-      is[jsect-1][y-1]  = ssect ? chrC4 : chrCD; 
-   else 
-      if (is[jsect-1][y-1] == chrB3) 
-         is[jsect-1][y-1]  = ssect ? chrC5 : chrD8; 
-      else 
-         if (is[jsect-1][y-1] == chrBA) 
-            is[jsect-1][y-1]  = ssect ? chrD7 : chrCE; 
-         else 
-            return 1;
-   return 0; 
-}  /* The end of Lh's body */ 
-
-
-static void lv(void)
-{int c; 
-
-   c = is[isect-1][jsect-1];
-   
-   is[isect-1][jsect-1]           = 
-      c == chsp                   ? 
-         (ssect ? chrB3 : chrBA)  : 
-      c == chrC4                  ? 
-         (ssect ? chrC5 : chrD7)  : 
-      c == chrCD                  ? 
-         (ssect ? chrD8 : chrCE)  : c; 
-}   /* The end of Lv's body */ 
-
-
-static int isector(void)
-{int  k, y1, y2, vv, ss, pp=0, tt=0, sh=0; 
-
-   /* Nested function: lh */ 
-   /* Nested function: lv */ 
-
-   k = resl.mver; 
-   for (isect = 1; isect <= k; isect++) 
-   { 
-      {intsect *with1 = &resl.ints[isect-1]; 
-         y1 = with1->y; 
-         vv = with1->aliasvert; 
-         ss = with1->aliasslot;    
-      } 
-      jsect = 1; 
-      while (resr.ints[jsect-1].selfvert != vv || 
-             resr.ints[jsect-1].selfslot != ss) 
-         ++(jsect); 
-      {intsect *with1 = &resr.ints[jsect-1]; 
-         if (y1 == with1->y) 
-            ++(sh); 
-         else 
-            if (y1 == with1->y + ystep) 
-               ++(pp); 
-            else 
-               if (y1 == with1->y - ystep) 
-                  ++(tt); 
-      } 
-   } 
-   sh = tt > sh ? - ystep : pp > sh ?  ystep : 0; 
-   goto b;
-
-a: if (sh < 0) 
-      ++(sh); 
-   else 
-      --(sh); 
-
-b: pp = sh < 0 ? resl.mxy - sh : resr.mxy + sh; 
-   if (resr.mxy > pp) pp = resr.mxy; 
-   if (resl.mxy > pp) pp = resl.mxy; 
-   ++(pp); 
-   
-   for (isect = 1; isect <= k; isect++) 
-      for (jsect = 1; jsect <= pp; jsect++) 
-         is[isect-1][jsect-1] = chsp; 
-
-   for (isect = 1; isect <= k; isect++) 
-   { 
-      {intsect *with1 = &resl.ints[isect-1]; 
-         y1 = with1->y; 
-         ssect = with1->sp % 2 == 0 ? TRUE : FALSE; 
-         vv = with1->aliasvert; 
-         ss = with1->aliasslot;    
-      }    
-      jsect = 1; 
-      while (resr.ints[jsect-1].selfvert != vv || 
-             resr.ints[jsect-1].selfslot != ss) 
-         ++(jsect); 
-      y2 = resr.ints[jsect-1].y; 
-      if (sh < 0) 
-         y1 -= sh; 
-      else 
-         y2 += sh; 
-      if (y1 == y2) 
-         for (jsect = 1; jsect <= k; jsect++) 
-            tt = lh(y1); 
-      else 
-         if (y1 < y2) 
-         { 
-            for (jsect = 1; jsect <= isect - 1; jsect++) 
-               if (lh(y1) == 1) 
-                  goto a;
-            if (is[isect-1][y1-1] != chsp) 
-               goto a;
-            is[isect-1][y1-1] = ssect ? chrBF : chrBB; 
-            for (jsect = y1 + 1; jsect <= y2 - 1; jsect++) 
-               lv(); 
-            if (is[isect-1][y2-1] != chsp) 
-               goto a;
-            is[isect-1][y2-1] = ssect ? chrC0 : chrC8; 
-            for (jsect = isect + 1; jsect <= k; jsect++) 
-               if (lh(y2) == 1) 
-                  goto a;
-         } 
-         else 
-         { 
-            for (jsect = 1; jsect <= isect - 1; jsect++) 
-               if (lh(y1) == 1) 
-                  goto a;
-            if (is[isect-1][y1-1] != chsp) 
-               goto a;
-            is[isect-1][y1-1] = ssect ? chrD9 : chrBC; 
-            for (jsect = y2 + 1; jsect <= y1 - 1; jsect++) 
-               lv(); 
-            if (is[isect-1][y2-1] != chsp) 
-               goto a;
-            is[isect-1][y2-1] = ssect ? chrDA : chrC9; 
-            for (jsect = isect + 1; jsect <= k; jsect++) 
-               if (lh(y2) == 1) 
-                  goto a;
-         } 
-   } 
-   return sh; 
-}  /* The end of Isector's body */ 
 
 
 static void diaprt(pnt* fout)
@@ -652,18 +528,23 @@ static void diaprt(pnt* fout)
  int  sh, p, k, kk; 
  pnt      po, pn = NULL; 
 
-
-   left = TRUE; 
+   left = 1; 
    diaprin(&resl);
-   left = FALSE; 
+   left = 0; 
    diaprin(&resr); 
-   sh = isector(); 
+
+ 
+sh=0;   
    kk = scrwidth - resl.mhor - resl.mver - resr.mhor - 2; 
    if (kk < 0) kk = 0; 
    kk = kk / 2; 
    r = sh < 0 ? resl.mxy - sh : resr.mxy + sh; 
    if (resr.mxy > r) r = resr.mxy; 
    if (resl.mxy > r) r = resl.mxy; 
+
+//for(j=0;j<r;j++) for(i=0;i<resl.mver;i++)  is[i][j]=' ';
+
+   
    p = 68 - 1 - kk - resl.mhor - resl.mver - resr.mhor;   
 /* Pukhov   80 -> 68  */ 
    ++(r); 
@@ -702,13 +583,16 @@ static void diaprt(pnt* fout)
             k += resl.mhor;
          }
       for (i = 0; i < resl.mver; i++) 
-         pn->stn[k + i] = is[i][j-1];
+         pn->stn[k + i] = ' ';  //   is[i][j-1];
       k += i;
+/*      
 #ifdef BLOCK_GRAPHICS
       pn->stn[k++] = '|';
 #else
       pn->stn[k++] = '!';
 #endif
+*/
+      pn->stn[k++] = ' ';
       if (sh > 0) 
          if (j <= sh)
          {
@@ -775,7 +659,7 @@ void writeAmDiagram(vampl* diag1,int label,char comment,FILE* outfile)
    }
    
    debug=label;
-   left = TRUE;
+   left = 1;
    diaprin(&resl); 
    for(i=0;i<yend;i++)
    {char ss[xend+1];
@@ -790,7 +674,9 @@ void writeAmDiagram(vampl* diag1,int label,char comment,FILE* outfile)
 
 
 void writeTextDiagram(vcsect* diag1,int label,char comment,FILE* outfile)
-{pnt  pp, pict; 
+{  pnt  pp, pict; 
+//   outfile=stdout;
+// deep=0;
    diag= *diag1;
    debug=label;
    diaprt(&pp); 
