@@ -19,7 +19,7 @@ void  cheplabel(void)
      scrcolor(Blue,LightGray);
      goto_xy(7,Y); print("CalcHEP - a package for Calculation in High Energy Physics");
      scrcolor(FGmain,BGmain);
-     goto_xy(15,Y+1);  print("Version 3.7.5: Last correction  April 23, 2019");
+     goto_xy(15,Y+1);  print("Version 3.8.2: Last correction  March 11, 2020");
    }
    { int Y=6;
      scrcolor(FGmain,BGmain); 
@@ -27,7 +27,7 @@ void  cheplabel(void)
      scrcolor(Blue,LightGray);
      print(" Alexander Pukhov(Skobeltsyn Institute of Nuclear Physics,Moscow)");
      goto_xy(4+8,Y++);print(" Alexander Belyaev(University of Southampton)"); 
-     goto_xy(4+8,Y++);print(" Neil Christensen (University of Pittsburgh)");
+     goto_xy(4+8,Y++);print(" Neil Chistensen (University of Pittsburgh)");
    }
 
    { int Y=10;
