@@ -2,7 +2,6 @@
 #include <sys/types.h>
 #include <unistd.h>
 #include <sys/wait.h>
-#include <signal.h>
 
 #include "chep_crt.h"
 #include "syst2.h"
@@ -50,7 +49,7 @@ static  int checkAuxDir( int nmod)
    if(i!=5)
    { 
      int dirStat=checkDir("results");
-     if(dirStat && blind==0)
+     if(dirStat)
      {  messanykey( 10,10,"There are files in directory 'results/'.\n"  
                           "To continue you has to clean or rename this directory.");
         viewresults();
@@ -60,7 +59,6 @@ static  int checkAuxDir( int nmod)
      system("if(test -d results/aux) then\n"
             "rm  -r results/aux\n"
             "fi\n"
-            "rm -f results/* \n"
             "mkdir results/aux; cd results/aux;\n"
             " mkdir models tmp results so_generated");
      for(i=0;i<5;i++)
@@ -114,7 +112,12 @@ int main(int argc,char** argv)
 
 
   blind=0;
-  strcpy(pathtocalchep,argv[0]);
+  if(strlen(argv[0])>1000) 
+  {  
+     printf("Too long path to CalcHEP directory. Maximal path length is 1000\n"); 
+     exit(1);
+  }
+  strcpy(pathtocalchep,argv[0]);  
   for(n=strlen(pathtocalchep)-1; n && pathtocalchep[n]!=f_slash; n--);
   pathtocalchep[n-3]=0;
   if(pathtocalchep[0]!='/')
@@ -129,6 +132,7 @@ int main(int argc,char** argv)
     strcpy(pathtocalchep,buff);
     free(buff);                         
   }
+  setenv("CALCHEP", pathtocalchep,1);
                                            
      
    for ( n=1;n<argc;n++) 
@@ -199,15 +203,15 @@ int main(int argc,char** argv)
               readModelFiles("./models",n_model);
               break; 
    }
-
+   newCodes=0;
    switch (menulevel)
    {
       case 2:  menuhelp();
                goto label_20;
       case 3:  goto label_31;
       case 4:  goto label_40;
-      case 5:  goto label_50;
-      case 6:  
+      case 5:  newCodes=1; 
+      case 6:  goto label_50;
       case 10: goto restart2;
    }
         
@@ -506,7 +510,6 @@ restart2:
                 }
               }
               if(totC)  newCodes=1;  
-                          
               free(pow);
               free(pids);   
               free(pipes);
@@ -542,7 +545,7 @@ restart2:
 label_50:
    k5=1;
    pscr5=NULL;
-   menulevel=5;
+   if(newCodes) menulevel=5; else menulevel=6;
    saveent(menulevel);
    sq_diagramsinfo();
       
@@ -569,44 +572,36 @@ label_50:
       switch (k5)
       {  case 0: goto label_40;  break;
          case 1:
-           c_prog(); newCodes=0; saveent(menulevel);
+           system("cd results; rm -f n_calchep lib_0.a ld*.a lf*.*" );
+           c_prog(); newCodes=0; menulevel=6; saveent(menulevel);
            break;
          case 2:
-           if(newCodes) { c_prog(); newCodes=0; saveent(menulevel);}
-          n_calchep_id=setLockFile("results/.lock"); 
+           if(newCodes) 
+           { system("cd results; rm -f n_calchep lib_0.a ld*.a lf*.*");
+             c_prog(); newCodes=0; menulevel=6;saveent(menulevel);
+           }
+           n_calchep_id=setLockFile("results/.lock"); 
            if(n_calchep_id)
            {
-             if(nPROCSS)
-             { chdir("results"); 
-                makeVandP(0,"../models",n_model,2,pathtocalchep);
-               pCompile();               
-               if(access("./n_calchep",X_OK)==0)
-               { 
+             
+             chdir("results"); 
+             makeVandP(0,"../models",n_model,2,pathtocalchep);
+             pCompile(); 
+             if(access("./n_calchep",X_OK)==0)
+             { 
+                if(!blind)
+                {
                   fflush(NULL); 
                   pid=fork();   
                   if(pid==0) 
                   {
-                    system("./n_calchep");
-                    exit(0);
-                  }    
-               } else messanykey(15,15,"n_calchep is not generated");
-               chdir("../");
-             } else                       
-             { fflush(NULL); 
-               pid=fork();
-               if(pid==0)
-               {  if(chdir("results")==0)
-                  {   char*command=malloc(150+strlen(pathtocalchep));
-                      makeVandP(0,"../models",n_model,2,pathtocalchep); 
-                      sprintf(command,"command=\"%s/sbin/make__n_calchep %d\"; xterm=`which xterm`; if(test -n \"$xterm\") then   $xterm -e $command; else $command; fi", pathtocalchep,n_model);                                 
-                      system(command);
-                      free(command);
-                      system("./n_calchep");                     
-                   }
-                   exit(0);    
-               }
-             }
-             unLockFile(n_calchep_id); 
+                     system("./n_calchep");
+                     exit(0);
+                  }
+                } else printf("results/n_calchep is generated\n");     
+             } else messanykey(15,15,"n_calchep is not generated");
+             chdir("../");
+             unLockFile(n_calchep_id);
            } 
            break;
          case 3: if(edittable(1,1,&modelTab[4],1," ",0))
