@@ -15,6 +15,7 @@ typedef struct
 extern ModelPrtclsStr*ModelPrtcls;
 extern int nModelVars;
 extern int nModelFunc;
+extern int*currentVarPtr;
 extern char**varNames;
 extern REAL *varValues;
 extern int calcMainFunc(void);
@@ -23,12 +24,8 @@ extern int calcMainFunc(void);
 
 extern double usrFF_(int n_in, int n_out,double * pvect,char**pnames,int*pdg);
 extern double usrfun_(char * name,int n_in, int n_out, double * pvect,char**pnames,int*pdg);
-extern double SQMEUSR_(int nsub, double GG,REAL*pvect,REAL*cb_coeff, int * err);
-
 extern double usrFF(int n_in, int n_out,double * pvect,char**pnames,int*pdg);
 extern double usrfun(char * name,int n_in, int n_out, double * pvect,char**pnames,int*pdg);
-extern double SQMEUSR(int nsub, double GG,REAL*pvect,REAL*cb_coeff, int * err);
-
 
 extern double alpha_lha(double q );
 extern void   getdatapath(char* dirpath, int len);
