@@ -7,9 +7,6 @@ double usrFF_(int n_in, int n_out,double * pvect,char**pnames,int*pdg)
 { return  usrFF(n_in,n_out,pvect,pnames,pdg);}
 double usrfun_(char * name,int n_in, int n_out,double * pvect,char**pnames,int*pdg) 
 { return  usrfun(name,n_in,n_out,pvect,pnames,pdg);}
-double SQMEUSR_(int nsub, double GG,REAL*pvect,REAL*cb_coeff, int * err)
-{ return SQMEUSR(nsub,GG,pvect,cb_coeff, err);}
-
 
 
 extern void   getdatapath_(char* dirpath, int len);
